==> prize-center-api-1.0.2-20180424.113949-1-sources.jar: cn/com/duiba/prize/center/api/dto/prize/ActivityOptionsDto.java <==
package cn.com.duiba.prize.center.api.dto.prize;

import java.io.Serializable;

/**
 * ClassName:DuibaHdtoolOptionsDto<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 兑吧活动工具奖项
 * @date 创建时间：2018/3/22  17:03
 * @since JDK 1.8
 **/
public class ActivityOptionsDto implements Serializable{

    private static final long serialVersionUID = 3860218183237470069L;
    
    public static final String ACTIVITY_TYPE_PLUGIN = "plugin";//插件活动
    public static final String ACTIVITY_TYPE_HDTOOL = "hdtool";//活动工具

    private Long id;//奖项id
    private Long duibaId;//兑吧id
    private Long opId;//入库活动id
    private String activityType;//活动类型
    private Integer payload;//排序
    private Long appItemId;//app商品id
    private Long itemId;//商品id
    private String prizeName;//奖品名称
    private String prizeType;//奖品类型
    private String facePrice;//实际价格
    private String logo;//奖品图片
    private Integer remaining;//剩余奖品数
    private String rate;//中奖概率
    private Boolean hidden;//奖品展示
    private String description;//奖品文案说明
    private Integer limitCount;//中奖限制
    private Integer minComein;//保底人数
    private Boolean deleted;//删除表示
    private Boolean autoOpen;//是否立即开奖（竞猜使用）
    private Integer rolling;//是否将奖项设置为中奖轮播内容  0:否 1:是
    private Long stockId;//库存中心库存ID
    
    private Boolean valid;//不是数据库字段
    private Boolean addrlimit;//不是数据库字段
    private String itemName;//不是数据库字段
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getDuibaId() {
		return duibaId;
	}
	public void setDuibaId(Long duibaId) {
		this.duibaId = duibaId;
	}
	public Long getOpId() {
		return opId;
	}
	public void setOpId(Long opId) {
		this.opId = opId;
	}
	public String getActivityType() {
		return activityType;
	}
	public void setActivityType(String activityType) {
		this.activityType = activityType;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public Long getAppItemId() {
		return appItemId;
	}
	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public String getPrizeName() {
		return prizeName;
	}
	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public String getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public String getRate() {
		return rate;
	}
	public void setRate(String rate) {
		this.rate = rate;
	}
	public Boolean getHidden() {
		return hidden;
	}
	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public Integer getMinComein() {
		return minComein;
	}
	public void setMinComein(Integer minComein) {
		this.minComein = minComein;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Boolean getAutoOpen() {
		return autoOpen;
	}
	public void setAutoOpen(Boolean autoOpen) {
		this.autoOpen = autoOpen;
	}
	public Integer getRolling() {
		return rolling;
	}
	public void setRolling(Integer rolling) {
		this.rolling = rolling;
	}
	public Long getStockId() {
		return stockId;
	}
	public void setStockId(Long stockId) {
		this.stockId = stockId;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public Boolean getAddrlimit() {
		return addrlimit;
	}
	public void setAddrlimit(Boolean addrlimit) {
		this.addrlimit = addrlimit;
	}
	public String getItemName() {
		return itemName;
	}
	public void setItemName(String itemName) {
		this.itemName = itemName;
	}

}

==> prize-center-api-1.0.9-20180525.083130-1-sources.jar: cn/com/duiba/prize/center/api/dto/prize/ActivityOptionsDto.java <==
package cn.com.duiba.prize.center.api.dto.prize;

import java.io.Serializable;

/**
 * ClassName:DuibaHdtoolOptionsDto<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: 兑吧活动工具奖项
 * @date 创建时间：2018/3/22  17:03
 * @since JDK 1.8
 **/
public class ActivityOptionsDto implements Serializable{

    private static final long serialVersionUID = 3860218183237470069L;
    
    public static final String ACTIVITY_TYPE_PLUGIN = "plugin";//插件活动
    public static final String ACTIVITY_TYPE_HDTOOL = "hdtool";//活动工具

    private Long id;//奖项id
    private Long duibaId;//兑吧id
    private Long opId;//入库活动id
    private String activityType;//活动类型
    private Integer payload;//排序
    private Long appItemId;//app商品id
    private Long itemId;//商品id
    private String prizeName;//奖品名称
    private String prizeType;//奖品类型
    private String facePrice;//实际价格
    private String logo;//奖品图片
    private Integer remaining;//剩余奖品数
    private String rate;//中奖概率
    private Boolean hidden;//奖品展示
    private String description;//奖品文案说明
    private Integer limitCount;//中奖限制
    private Integer minComein;//保底人数
    private Boolean deleted;//删除表示
    private Boolean autoOpen;//是否立即开奖（竞猜使用）
    private Integer rolling;//是否将奖项设置为中奖轮播内容  0:否 1:是
    private Long stockId;//库存中心库存ID
    private String otherUse;//目前改字段在 签到里面使用
    private Integer stockWarning;/** 是否库存报警 0:否 1:是    插件字段*/
    private String prizesLimit;//发奖限制 json格式  ActivityPrizeOptionLimitDto  插件字段  活动工具里面没有
    
    private Boolean valid;//不是数据库字段
    private Boolean addrlimit;//不是数据库字段
    private String itemName;//不是数据库字段
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getDuibaId() {
		return duibaId;
	}
	public void setDuibaId(Long duibaId) {
		this.duibaId = duibaId;
	}
	public Long getOpId() {
		return opId;
	}
	public void setOpId(Long opId) {
		this.opId = opId;
	}
	public String getActivityType() {
		return activityType;
	}
	public void setActivityType(String activityType) {
		this.activityType = activityType;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public Long getAppItemId() {
		return appItemId;
	}
	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public String getPrizeName() {
		return prizeName;
	}
	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public String getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public String getRate() {
		return rate;
	}
	public void setRate(String rate) {
		this.rate = rate;
	}
	public Boolean getHidden() {
		return hidden;
	}
	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public Integer getMinComein() {
		return minComein;
	}
	public void setMinComein(Integer minComein) {
		this.minComein = minComein;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Boolean getAutoOpen() {
		return autoOpen;
	}
	public void setAutoOpen(Boolean autoOpen) {
		this.autoOpen = autoOpen;
	}
	public Integer getRolling() {
		return rolling;
	}
	public void setRolling(Integer rolling) {
		this.rolling = rolling;
	}
	public Long getStockId() {
		return stockId;
	}
	public void setStockId(Long stockId) {
		this.stockId = stockId;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public Boolean getAddrlimit() {
		return addrlimit;
	}
	public void setAddrlimit(Boolean addrlimit) {
		this.addrlimit = addrlimit;
	}
	public String getItemName() {
		return itemName;
	}
	public void setItemName(String itemName) {
		this.itemName = itemName;
	}
	public String getOtherUse() {
		return otherUse;
	}
	public void setOtherUse(String otherUse) {
		this.otherUse = otherUse;
	}
	public Integer getStockWarning() {
		return stockWarning;
	}
	public void setStockWarning(Integer stockWarning) {
		this.stockWarning = stockWarning;
	}
	public String getPrizesLimit() {
		return prizesLimit;
	}
	public void setPrizesLimit(String prizesLimit) {
		this.prizesLimit = prizesLimit;
	}
}
